@@ -4,6 +4,7 @@ from collections import defaultdict
 
 from django.core import serializers
 from django.core.management.base import BaseCommand, CommandError
+from django.core.management.color import no_style
 from django.db import connections, router, transaction, DEFAULT_DB_ALIAS
 from django.core.exceptions import ObjectDoesNotExist
 
@@ -43,6 +44,8 @@ class Command(BaseCommand):
         connection = connections[using]
         cursor = connection.cursor()
 
+        self.style = no_style()
+
         transaction.commit_unless_managed(using=using)
         transaction.enter_transaction_management(using=using)
         transaction.managed(True, using=using)
