@@ -135,7 +135,7 @@ class SiteTree(object):
         """Initializes local cache from Django cache."""
         cache_ = cache.get('sitetrees')
         if cache_ is None:
-            # Init cache dictionary with predefined enties.
+            # Init cache dictionary with predefined entries.
             cache_ = {'sitetrees': {}, 'urls': {}, 'parents': {}, 'items_by_ids': {}, 'tree_aliases': {}}
         self.cache = cache_
 
@@ -274,12 +274,15 @@ class SiteTree(object):
         request path against URL of given tree item.
 
         """
+        if self._global_context.current_app == 'admin':
+            return None
+
         current_item = None
 
-        if 'request' not in self._global_context and self._global_context.current_app != 'admin':
+        if 'request' not in self._global_context:
             raise SiteTreeError('Sitetree needs "django.core.context_processors.request" to be in TEMPLATE_CONTEXT_PROCESSORS in your settings file. If it is, check that your view pushes request data into the template.')
         else:
-            # urlquote is a try to support non-ascii in url.
+            # urlquote is an attempt to support non-ascii in url.
             current_url = urlquote(self._global_context['request'].path)
             urls_cache = self.get_cache_entry('urls', tree_alias)
             if urls_cache:
@@ -366,7 +369,7 @@ class SiteTree(object):
                 url_tag(template.Parser(None), template.Token(token_type=template.TOKEN_BLOCK, contents=url_token)).render(context)
 
                 # We make an anchor link from an unresolved URL as a reminder.
-                if context['item.url_resolved'] == '':
+                if not context['item.url_resolved']:
                     resolved_url = u'#unresolved'
                 else:
                     resolved_url = context['item.url_resolved']
@@ -396,14 +399,28 @@ class SiteTree(object):
 
     def get_current_page_title(self, tree_alias, context):
         """Returns resolved from sitetree title for current page."""
+        return self.get_current_page_attr('title_resolved', tree_alias, context)
+
+    def get_current_page_attr(self, attr_name, tree_alias, context):
+        """Returns an arbitrary attribute of a sitetree item resolved as current for current page."""
         tree_alias, sitetree_items = self.init_tree(tree_alias, context)
         current_item = self.get_tree_current_item(tree_alias)
-        # Current item unresolved, fail silently.
+        # Current item is unresolved, fail silently.
         if current_item is None:
             if settings.DEBUG:
-                raise SiteTreeError('Unable to resolve title for current page using sitetree_page_title tag. Check whether there is an appropriate sitetree item defined for current URL.')
+                raise SiteTreeError('Unable to resolve current sitetree item to get a `%s` for current page. Check whether there is an appropriate sitetree item defined for current URL.' % attr_name)
             return ''
-        return current_item.title_resolved
+        return getattr(current_item, attr_name, '')
+
+    def get_ancestor_level(self, current_item, deep=1):
+        """Returns ancestor of level `deep` recursively"""
+        if current_item.parent is not None:
+            if deep <= 1:
+                return current_item.parent
+            else:
+                return self.get_ancestor_level(current_item.parent, deep=deep-1)
+        else:
+            return current_item
 
     def menu(self, tree_alias, tree_branches, context):
         """Builds and returns menu structure for 'sitetree_menu' tag."""
@@ -434,6 +451,9 @@ class SiteTree(object):
             elif branch_id == 'this-siblings' and current_item is not None:
                 branch_id = current_item.parent.id
                 parent_ids.append(branch_id)
+            elif branch_id == 'this-parent-siblings' and current_item is not None:
+                branch_id = self.get_ancestor_level(current_item, deep=2).id
+                parent_ids.append(branch_id)
             elif branch_id.isdigit():
                 parent_ids.append(int(branch_id))
             else:
@@ -441,7 +461,7 @@ class SiteTree(object):
 
         menu_items = []
         for item in sitetree_items:
-            if item.hidden == False and item.inmenu and self.check_access(item, context):
+            if not item.hidden and item.inmenu and self.check_access(item, context):
                 if item.parent is None:
                     if parent_isnull:
                         menu_items.append(item)
@@ -476,7 +496,7 @@ class SiteTree(object):
                 if len(item.perms) != len(item.perms.intersection(user_perms)):
                     return False
             else:
-                if len(item.perms.intersection(user_perms)) == 0:
+                if not len(item.perms.intersection(user_perms)):
                     return False
         return True
 
@@ -544,7 +564,7 @@ class SiteTree(object):
             children = self.get_children(tree_alias, tree_item)
             children = self.filter_items(children, navigation_type)
             children = self.apply_hook(children, '%s.has_children' % navigation_type)
-            tree_item.has_children = len(children)>0
+            tree_item.has_children = len(children) > 0
             items.append(tree_item)
         return items
 
@@ -556,8 +576,8 @@ class SiteTree(object):
         if self._global_context.current_app != 'admin':
             for item in items:
                 no_access = not self.check_access(item, self._global_context)
-                hidden_for_nav_type = navigation_type is not None and getattr(item, 'in' + navigation_type, False) != True
-                if item.hidden == True or no_access or hidden_for_nav_type:
+                hidden_for_nav_type = navigation_type is not None and not getattr(item, 'in' + navigation_type, False)
+                if item.hidden or no_access or hidden_for_nav_type:
                     items_out.remove(item)
         return items_out
 
