@@ -133,7 +133,7 @@ def sitetree_url(parser, token):
             as_var = tokens[-1]
             tokens = tokens[:-2]
         sitetree_item = parser.compile_filter(tokens[2])
-        tag_arguments = map(parser.compile_filter, tokens[3:])
+        tag_arguments = list(map(parser.compile_filter, tokens[3:]))
         if not tag_arguments:
             tag_arguments = None
         return sitetree_urlNode(sitetree_item, as_var, tag_arguments)
@@ -143,10 +143,7 @@ def sitetree_url(parser, token):
 
 @register.tag
 def sitetree_page_title(parser, token):
-    """Renders title for current page, resolved against sitetree item
-    representing current URL.
-
-    """
+    """Renders a title for current page, resolved against sitetree item representing current URL."""
     tokens = token.split_contents()
 
     if len(tokens) == 3:
@@ -156,6 +153,18 @@ def sitetree_page_title(parser, token):
         raise template.TemplateSyntaxError("%r tag requires two arguments. E.g. {%% sitetree_page_title from \"mytree\" %%}." % tokens[0])
 
 
+@register.tag
+def sitetree_page_description(parser, token):
+    """Renders a description for the current page, resolved against sitetree item representing current URL."""
+    tokens = token.split_contents()
+
+    if len(tokens) == 3:
+        tree_alias = parser.compile_filter(tokens[2])
+        return sitetree_page_descriptionNode(tree_alias)
+    else:
+        raise template.TemplateSyntaxError("%r tag requires two arguments. E.g. {%% sitetree_page_description from \"mytree\" %%}." % tokens[0])
+
+
 class sitetree_treeNode(template.Node):
     """Renders tree items from specified site tree."""
 
@@ -222,7 +231,7 @@ class sitetree_urlNode(template.Node):
 
 
 class sitetree_page_titleNode(template.Node):
-    """Renders page title from specified site tree."""
+    """Renders a page title from the specified site tree."""
 
     def __init__(self, tree_alias):
         self.tree_alias = tree_alias
@@ -231,6 +240,16 @@ class sitetree_page_titleNode(template.Node):
         return sitetree.get_current_page_title(self.tree_alias, context)
 
 
+class sitetree_page_descriptionNode(template.Node):
+    """Renders a page description from the specified site tree."""
+
+    def __init__(self, tree_alias):
+        self.tree_alias = tree_alias
+
+    def render(self, context):
+        return sitetree.get_current_page_attr('description', self.tree_alias, context)
+
+
 def detect_clause(parser, clause_name, tokens):
     """Helper function detects a certain clause in tag tokens list.
     Returns its value.
